@@ -796,6 +796,8 @@ def test_true_color_cpu():
     blue_dask = create_test_arr(arr3, backend='dask')
     dask_result = true_color(red_dask, green_dask, blue_dask)
 
-    assert np.isclose(
-        np.asarray(numpy_result), np.asarray(dask_result), equal_nan=True
-    ).all()
+    # TODO: test output metadata: dims, coords, attrs
+    assert isinstance(numpy_result, xa.DataArray)
+    assert isinstance(dask_result.data, da.Array)
+    dask_result.data = dask_result.data.compute()
+    assert np.isclose(numpy_result, dask_result, equal_nan=True).all()
